#====Load Packages====
library(tidyverse)
library(car)
library(viridis)
library(lme4)
library(mgcv)
library(ggrepel)
library(cowplot)


#====Load Data===== 
IR = read_csv("../Data/Lichen_IR.csv")
Veg = read_csv("../Data/FLG_Surrounding_Vegetation.csv")
Points = read_csv("../Data/FLG_Transect_Points.csv")



#===Set Aesthetics====
theme_set(theme_bw()+
            theme(panel.grid = element_blank(),
            legend.text.align = 0,
            legend.position = "bottom",
            legend.key.width = unit(1.5, "lines")))


lichenfill = scale_fill_manual(values = c("#edf8b1", "#225ea8"),
                               labels = c(expression(italic("F. cucullata")), expression(italic("P. leucophlebia"))))
lichencolors = scale_color_manual(values = c("#edf8b1", "#225ea8"),
                                  labels = c(expression(italic("F. cucullata")), expression(italic("P. leucophlebia"))))

lichenlines = scale_linetype_manual(values = c("solid", "dashed"),
                                    labels = c(expression(italic("F. cucullata")), expression(italic("P. leucophlebia"))))

lichenpoint =   scale_shape_manual(values = c(21, 23), 
                                   labels = c(expression(italic("F. cucullata")), expression(italic("P. leucophlebia"))))


#====Prep Data====
IR = IR%>%
  mutate(photobiont = height/111,
         species = substr(plot,1,1),
         identifier = paste(plot,lichen,sep = "_")) #111 pixels to one micrometer unit

Points = Points%>%
  rowwise()%>%
  mutate(Standard_UTM = str_replace(Standard_UTM,"28 N ",""), #Removes characters
         Standard_UTM = str_replace(Standard_UTM, "mE",""),
         Standard_UTM = str_replace(Standard_UTM, "mN",""),
         Easting = unlist(str_split(Standard_UTM," "))[1],
         Easting = as.numeric(Easting),
         Northing = unlist(str_split(Standard_UTM," "))[2],
         Northing = as.numeric(Northing))

#get lake shore
Lake = Points%>% filter(Name == "GOEND S")

#calculate distance 
distance = Points%>% 
  filter(!Name %in% c("GOSTART S", "Gostartflg", "GOEND S")) %>% 
  mutate(distance = sqrt((Northing-Lake$Northing)^2+(Easting-Lake$Easting)^2)) %>% 
  mutate(species = ifelse(str_detect(tolower(Name), "c"), "C",
                          ifelse(str_detect(tolower(Name), "p"), "P", NA)))

IR_dist = IR%>% 
  left_join(distance%>%
              rename(plot = Name)%>% 
              select(plot, distance))

#Average ENDVI and photobiont thickness within an individual
Lichen = IR_dist%>% 
  group_by(plot,identifier,species,distance)%>%
  summarize(photobiont=mean(photobiont),
            ENDVI = mean(ENDVI)) %>% 
  ungroup %>% 
  group_by(species) %>% 
  mutate(dist.mean = mean(distance),
         dist.sd = sd(distance),
         dist.z = (distance - dist.mean)/dist.sd) %>%  #z scored distance
  ungroup

#remove lichen, which includes focal species, and recalculate percent cover
Veg_adj = Veg%>% select(-contains("Perc_cover"),-contains("Sum"), -Lichen)%>%
  mutate(total = Grass+Rock+Soil+Moss+Heathland,
         Grass=Grass/total,
         Rock=Rock/total,
         Soil=Soil/total,
         Moss=Moss/total,
         Heathland=Heathland/total)


####Differences in Habitat Between Species#####
#combine percent cover information with metadata on species identity and distance
veg <- Veg_adj %>% 
  select(-total) %>% 
  left_join(Lichen %>% 
              select(plot, species, distance) %>% 
              unique())


#create a matrix
vmat1 <- veg %>% 
  select(plot, Grass:Heathland)

vmat <- as.matrix(vmat1[,-1])
row.names(vmat) <- vmat1$plot

#calculate a PCA
pca <- prcomp(vmat)
summary(pca)

#extract scores of individual datapoints
scores <- data.frame(pca$x)

scores$plot = row.names(scores)

#extract vectors
loadings <- data.frame(pca$rotation)

loadings$cover <- row.names(loadings)

scaleloadings <- 0.7



#====Plot Figure 2====
fig2 <- scores %>% 
  left_join(veg) %>% 
  ggplot(aes(x = PC1, y = PC2, ))+
  stat_ellipse(aes(linetype = species), type = "t")+
  geom_hline(yintercept = 0, alpha = 0.2)+
  geom_vline(xintercept = 0, alpha = 0.2)+
  geom_point(aes(fill = distance, shape = species), size = 3, alpha = 0.7)+
  geom_segment(aes(x = 0,y = 0, xend = scaleloadings*PC1, yend = scaleloadings*PC2), arrow = arrow(length = unit(0.5, "lines")), data = loadings)+
  geom_label_repel(aes(label = cover, x = scaleloadings*PC1, y= scaleloadings*PC2), fill = alpha("white", 0.5), segment.size = 0.2, force = 1, box.padding= 0.5, data = loadings %>% mutate(cover = ifelse(cover == "Heathland", "Woody\nVegetation", cover)))+
  # scale_fill_gradient(low = "black", high = "white")+
  scale_fill_viridis(direction = -1, option = "plasma")+
  lichenpoint+
  # coord_equal()+
  lichenlines+
  labs(fill = "Distance\nfrom Mývatn",
       linetype = element_blank(),
       shape = element_blank())+
  theme(legend.box = "vertical",
        legend.margin = margin())


# ggpreview(plot = fig2, width = 3, height = 4, units = "in", dpi = 650)
# ggsave(plot = fig2, "../Figures/GO_Fig2.pdf", width = 3, height = 4, units = "in", dpi = 650)



#####Effects of Gradient on Species#####

#====Question 1: Distance====
#create a data frame of lichen presence and absence for each m along the transect
lichen_pres <- distance %>% 
  filter(str_detect(Name, "C")|str_detect(Name, "P")) %>% 
  mutate(distance = round(distance),
         species = ifelse(str_detect(Name, "C"), "C", "P"),
         C = ifelse(species == "C", 1,0),
         P = ifelse(species == "P", 1,0)) %>% 
  bind_rows(data.frame(distance = c(1:400), P = 0, C = 0)) %>% 
  group_by(distance) %>% 
  summarise(C = sum(C),
            P = sum(P)) %>% 
  mutate(C = ifelse(C>1,1,C),
         P = ifelse(P>1,1,P)) %>% 
  arrange(distance)

#convert to long format
lichen_pres_long <- lichen_pres %>% 
  gather(species, pres, C, P)%>% 
  mutate(species = as.factor(species))

#fit GAM with interaction
spgam <- gam(pres~s(distance, by = species), family = binomial(), data = lichen_pres_long, method = "ML") 

gamsplo <- gam(pres~s(distance), family = binomial(), data = lichen_pres_long, method = "ML") 


AIC(spgam, gamsplo)
anova(spgam, gamsplo, test = "Chisq")
summary(spgam)

#create a dataframe to store predicted data
dists <- data.frame(distance = 0:400)

pred_dists <- dists %>% 
  crossing(species = unique(lichen_pres_long$species)) %>% 
  mutate(pred = exp(predict(spgam, newdata = .)), #exponentiated because log link used
         predse = predict(spgam, newdata = ., se.fit = TRUE, type = "response")$se.fit)

# predict distributions 
pred_dist_long <- lichen_pres_long %>% 
  select(-pres) %>% 
  mutate(pres = exp(predict(spgam, .)), #exponentiated because log link used
         pres.se = predict(spgam, ., se.fit = TRUE, type = "response")$se.fit)

#====Plot Figure 3====
# upper panel
p1 <- pred_dist_long %>% 
  ggplot(aes(x = distance))+
  geom_ribbon(aes(ymin = (pres-pres.se), ymax = (pres+2*pres.se), fill = species, linetype = species), size = 0.25, color = "black", alpha = 0.5)+
  geom_line(aes(y = pres, linetype = species))+
  lichencolors+
  lichenfill+
  lichenlines+
  lichenpoint+
  labs(x = element_blank(),
       y = "Probability of lichen presence",
       fill = element_blank(),
       shape = element_blank(),
       linetype = element_blank()) +
  theme(legend.direction = "vertical",
        legend.position = c(0.7, 0.83),
        axis.title.y = element_text(vjust = -10),
        legend.box.background = element_blank(),
        legend.background = element_blank())

# lower panel
p2 <- distance %>% 
  mutate(species = ifelse(str_detect(Name, "C"), "F. cucullata", "P. leucophlebia")) %>% 
  ggplot(aes(x = distance, y = fct_rev(species)))+
  geom_point(shape = 124, col = "black", size = 4, alpha = 0.8)+
  lims(x = c(0, 400))+
  labs(x = "Distance from Mývatn",
       y = element_blank()) +
  theme(axis.text.y = element_text(face = "italic", color = "black"),
        axis.title.y = element_blank())

# combine
presplot <- plot_grid(p1, p2, ncol = 1, align = "v", rel_heights = c(1, 0.35))

ggsave(plot = presplot, "../Figures/GO_Fig3.pdf",  width = 3.5, height = 3.5, units = "in", dpi = 650, device = "pdf")

#===Question 2: Photobiont Thickness====

lmer(photobiont~distance * species + (1|plot), data = Lichen) #singular because plot explained no variance
photo <- lm(log(photobiont)~distance * species, data = Lichen)  

summary(photo)

#====Question 3: Chlorophyll=======

endvimod <- lmer(ENDVI~distance * species + (1|plot), data = Lichen)
summary(endvimod)
Anova(endvimod, test.statistic = "F")

#====Get predicted data===
#predicted fit
pred <- data.frame(distance = c(min(Lichen$distance):max(Lichen$distance))) %>%
  crossing(species = c("C", "P")) %>% 
  left_join(Lichen %>% 
              group_by(species) %>% 
              summarize(min = min(distance), max = max(distance))) %>% 
  filter(distance>=min,
         distance<=max) %>% 
  mutate(photobiont = predict(photo, .),
         photobiont.se = predict(photo,., se.fit = TRUE)$se.fit,
         ENDVI = predict(endvimod, ., re.form = NA, type = "response"))

# standard errors for mixed effects model
mm <- model.matrix(~distance*species, pred)

#calculate estimates
est <- mm %*% fixef(endvimod) 

vcov <- as.matrix(vcov(endvimod))

se <- apply(mm, 1, function(x){sqrt(t(x) %*% vcov %*% x) })

se <- data.frame(mm, estimate= est, se = se)


pred <- pred %>% 
  mutate(ENDVI.estimate = est,
         ENDVI.se = se$se) 

#check
pred %>% 
  filter(ENDVI.estimate!=ENDVI)



#====Plot Figure 4====
thickplot <- Lichen%>%
  ggplot(aes(x = distance, y= log(photobiont), fill = species))+
  geom_ribbon(aes(ymin = photobiont-2*photobiont.se, ymax = photobiont+2*photobiont.se, fill = species, linetype = species), size = 0.25, color = "black", alpha = 0.5,  data = pred)+
  geom_line(aes(y = photobiont, linetype = species), size = 1, data = pred)+
  geom_point(aes(shape = species), size = 3, alpha = 0.8)+
  lichencolors+
  lichenfill+
  lichenlines+
  lichenpoint+
  # scale_alpha_manual(values = c(1,0.8), guide = NULL)+
  ylab("Log(photobiont thickness)")+
  xlab("Distance from Mývatn (m)")+
  labs(color = element_blank(),
       linetype = element_blank(),
       fill = element_blank(),
       shape = element_blank())+
  theme(axis.title.x = element_blank())

endviplot <- Lichen%>%
  ggplot(aes(x = distance, y= ENDVI, fill = species))+
  geom_ribbon(aes(ymin = ENDVI-2*ENDVI.se, ymax = ENDVI+2*ENDVI.se, fill = species, linetype = species), size = 0.25, color = "black", alpha = 0.5,  data = pred)+
  geom_line(aes(linetype = species), size = 1, data = pred)+
  geom_point(aes(shape = species), alpha = 0.8, size = 3)+
  lichencolors+
  lichenfill+
  lichenpoint+
  ylab("Chlorophyll concentration (ENDVI)")+
  xlab("Distance from Mývatn (m)")+
  labs(color = element_blank(),
       fill = element_blank(),
       linetype = element_blank())+
  theme(legend.position = "none")


leg <- get_legend(thickplot)

thickplot2 <- thickplot+theme(legend.position = "none")

fig4.1 <- plot_grid(thickplot2, endviplot, ncol = 1, rel_heights = c(0.45, 0.5), labels= c("A", "B"))

fig4 <- plot_grid(fig4.1, leg, ncol =1, rel_heights=c(2, 0.1))
# ggpreview(plot = fig4, width = 3, height = 6, units = "in", dpi =650)
# ggsave(plot = fig4, "../Figures/GO_Fig4.pdf", width = 3, height = 6, units = "in", dpi =650, device = "pdf")
